<?php

declare(strict_types=1);

namespace Drupal\acquia_dam\Commands;

use Consolidation\AnnotatedCommand\CommandData;
use Drupal\acquia_dam\AcquiadamAuthService;
use Drush\Commands\DrushCommands;
use Drush\Drupal\Commands\sql\SanitizePluginInterface;
use Symfony\Component\Console\Input\InputInterface;

/**
 * Acquia DAM integration to SQL sanitize for Drush.
 */
final class SqlSanitizeCommands extends DrushCommands implements SanitizePluginInterface {

  /**
   * The auth service.
   *
   * @var \Drupal\acquia_dam\AcquiadamAuthService
   */
  private AcquiadamAuthService $authService;

  /**
   * Constructs a new SqlSanitizeCommands object.
   *
   * @param \Drupal\acquia_dam\AcquiadamAuthService $auth_service
   *   The auth service.
   */
  public function __construct(AcquiadamAuthService $auth_service) {
    parent::__construct();
    $this->authService = $auth_service;
  }

  /**
   * Removes Acquia DAM authentication information from the database.
   *
   * {@inheritdoc}
   *
   * @hook post-command sql-sanitize
   */
  public function sanitize($result, CommandData $commandData): void {
    $this->authService->disconnectSiteAndUsers();
    $this->logger()->success(dt('Acquia DAM authentication information remove.'));
  }

  /**
   * {@inheritdoc}
   *
   * @hook on-event sql-sanitize-confirms
   */
  public function messages(&$messages, InputInterface $input): void {
    $messages[] = dt('Remove Acquia DAM authentication information.');
  }

}
